<?php

/**
 * q-translate-x.class.php
 *
 * @author Dominik Kocuj <dominik@kocuj.pl>
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License v2 or later
 * @copyright Copyright (c) 2013-2016 Dominik Kocuj
 * @package kocuj_sitemap
 */

// set namespace
namespace KocujSitemapPlugin\Classes\MultipleLanguages;

// security
if ((!defined('ABSPATH')) || ((isset($_SERVER['SCRIPT_FILENAME'])) && (basename($_SERVER['SCRIPT_FILENAME']) === basename(__FILE__)))) {
	header('HTTP/1.1 404 Not Found');
	die();
}

/**
 * Multiple languages plugin class - qTranslate X
 *
 * @access public
 */
class QTranslateX extends QTranslate implements \KocujSitemapPlugin\Interfaces\MultipleLanguages {
	/**
	 * Singleton instance
	 *
	 * @access private
	 * @var object
	 */
	private static $instance = NULL;

	/**
	 * Constructor
	 *
	 * @access private
	 * @return void
	 */
	private function __construct() {
		// change translation plugin functions prefix
		$this->functionsPrefix = 'qtranxf';
	}

	/**
	 * Disable cloning of object
	 *
	 * @access private
	 * @return void
	 */
	private function __clone() {
	}

	/**
	 * Get singleton instance
	 *
	 * @access public
	 * @return object Singleton instance
	 */
	public static function getInstance() {
		// optionally create new instance
		if (!self::$instance) {
			self::$instance = new self();
		}
		// exit
		return self::$instance;
	}

	/**
	 * Get translated data
	 *
	 * @access protected
	 * @param string $origData Original data
	 * @param string $type Data type; can be "text", "url" or "term"
	 * @param string $locale Language locale
	 * @param string $termType Term type; used only when $type="term"; default: empty
	 * @param int $termId Term id; used only when $type="term"; default: empty
	 * @return string Translated data
	 */
	protected function getTranslatedData($origData, $type, $locale, $termType = '', $termId = 0) {
		// prepare languages list
		$this->prepareLanguages();
		// initialize
		$data = $origData;
		// translate data
		if (isset($this->languages[$locale])) {
			switch ($type) {
				case 'text':
				case 'url':
					$data = parent::getTranslatedData($origData, $type, $locale, $termType, $termId);
					break;
				case 'term':
					$data = call_user_func_array($this->functionsPrefix.'_use', array(
						$this->languages[$locale],
						$origData,
						false,
					));
					break;
			}
		}
		// exit
		return $data;
	}

	/**
	 * Get translation plugin name; it is used in administration panel during the selection of multi-lingual plugin
	 *
	 * @access public
	 * @return string Plugin name
	 */
	public function getName() {
		// get plugin name
		return 'qTranslate X';
	}

	/**
	 * Get plugin priority; it is used to sort translation plugins usage order; the lowest number is the first plugin in order, the highest number is the last plugin in order
	 *
	 * @access public
	 * @return string Plugin priority
	 */
	public function getPriority() {
		// get plugin priority
		return 10;
	}

	/**
	 * Check if translation plugin exists; this method checks if all functions, classes, methods, properties and global variables, which are used from translation plugin, exists
	 *
	 * @access public
	 * @return bool Translation plugin exists (true) or not (false)
	 */
	public function checkPlugin() {
		// check if qTranslate X plugin exists and has required functions, methods and variables implemented
		global $q_config;
		if ((!isset($q_config)) || (!is_array($q_config)) || (!function_exists($this->functionsPrefix.'_getSortedLanguages')) ||
			(!function_exists($this->functionsPrefix.'_use')) || (!function_exists($this->functionsPrefix.'_convertURL')) ||
			(!function_exists($this->functionsPrefix.'_use_term')) || (!function_exists($this->functionsPrefix.'_useCurrentLanguageIfNotFoundUseDefaultLanguage'))) {
			return false;
		}
		// exit
		return true;
	}

	/**
	 * Get translation plugin filename with its directory
	 *
	 * @access public
	 * @return string Translation plugin filename
	 */
	public function getPluginFile() {
		// get plugin name
		return 'qtranslate-x/qtranslate.php';
	}
}
